=========
Changelog
=========

Version 0.1.15
=============

- Added `--rsync` option to `pbsdeploy` command

Version 0.1.14
=============

- Fixed bug about `rsync` attribute checking

Version 0.1.13
=============

- Fixed some bugs
- Added `--rsync` option to `upload` and `download` commands, fixed #10
- Added status code checking to `upload` and `download` commands

Version 0.1.12
=============

- Updated `pbssub` command
- Added `pbsdeploy` command

Version 0.1.11
=============

- Fixed some bugs
- Added `pbsgen` command
- Added `pbsgen_example` command
- Added some data files

Version 0.1.10
=============

- Fixed Unix newline for `pbstemp` command
- Added `pbssub` command 
- Tested `pbscheck` command

Version 0.1.9
=============

- Fixed typo and some config

Version 0.1.7-0.1.8
=============
- Updated documentation
- Updated deployment code

Version 0.1.6
=============

- Implemented `run` command
- Implemented `upload` command
- Added `download` command
- Added `pbstemp` command
- Added `pbscheck` command

Version 0.1.5
=============

- Useless badge removed in README
- A pretty table function added to list hosts

Version 0.1.4
=============

- Python version dependency added: Python 3.4 or greater is required for loon
- Badges added to README.md

Version 0.1
===========

- Feature A added
- FIX: nasty bug #1729 fixed
- Feature host management added
